@@ -26,6 +26,7 @@ import itertools
 import json
 import numpy as np
 import pickle
+import sys
 
 from dataiter import deco
 from dataiter import util
@@ -544,6 +545,34 @@ class DataFrame(dict):
         """
         print(self.to_string(max_rows, max_width))
 
+    def print_memory_use(self):
+        """
+        Print memory use by column and total.
+
+        >>> data = di.DataFrame.read_csv("data/listings.csv")
+        >>> data.print_memory_use()
+        """
+        mem = DataFrame()
+        for name, column in self.items():
+            new = DataFrame(column=name)
+            new.dtype = str(column.dtype)
+            new.item_size = column.itemsize
+            if column.is_object():
+                new.total_size = sum(sys.getsizeof(x) for x in column)
+            else:
+                new.total_size = column.nbytes
+            mem = mem.rbind(new)
+        new = DataFrame(column="TOTAL")
+        new.dtype = "--"
+        new.item_size = mem.item_size.sum()
+        new.total_size = mem.total_size.sum()
+        mem = mem.rbind(new)
+        # Format sizes into sensible values for display.
+        mem.item_size = [f"{x:.0f} B" for x in mem.item_size]
+        mem.total_size = [f"{x/1024**2:,.0f} MB" for x in mem.total_size]
+        mem.colnames = [x.upper() for x in mem.colnames]
+        print(mem)
+
     def print_missing_counts(self):
         """
         Print counts of missing values by column.
@@ -551,12 +580,15 @@ class DataFrame(dict):
         >>> data = di.DataFrame.read_csv("data/listings.csv")
         >>> data.print_missing_counts()
         """
-        print("Missing counts:")
+        nas = DataFrame()
         for name in self.colnames:
             n = self[name].is_missing().sum()
             if n == 0: continue
-            pc = 100 * n / self.nrow
-            print(f"... {name}: {n} ({pc:.1f}%)")
+            nas = nas.rbind(DataFrame(column=name, nna=n))
+        if not nas: return
+        nas.pna = [f"{100*x/self.nrow:.1f}%" for x in nas.nna]
+        nas.colnames = [x.upper() for x in nas.colnames]
+        print(nas)
 
     @deco.new_from_generator
     def rbind(self, *others):
